@@ -148,7 +148,7 @@ find_transidx (time_t *transitions, ttinfo *types, int *trans_idx, long int num_
 	idx = trans_idx [i];
 	types [idx].isdst ? (*dstidx = i) : (*stdidx = i);
 	
-	if (i >= num_trans - 1) 
+	if (i >= num_trans) 
 		i--;
 	else 
 		i++;
@@ -409,6 +409,8 @@ error:
 				free (types [i].zname);
 		free (types);
 	}
+	if (znames)
+		free (znames);
 	free (full_path);
 	if (leaps)
 		free (leaps);
