@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -49,7 +49,7 @@ static CamelStoreClass *parent_class = NULL;
 CamelType
 camel_offline_store_get_type (void)
 {
-	static CamelType type = 0;
+	static CamelType type = NULL;
 	
 	if (!type) {
 		type = camel_type_register (CAMEL_STORE_TYPE,
