@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -28,10 +28,12 @@
 #include <string.h>
 #include <time.h>
 
+#include <glib.h>
+#include <glib/gi18n-lib.h>
+
 #include "camel-sasl-popb4smtp.h"
 #include "camel-service.h"
 #include "camel-session.h"
-#include "camel-i18n.h"
 
 CamelServiceAuthType camel_sasl_popb4smtp_authtype = {
 	N_("POP before SMTP"),
@@ -108,13 +110,13 @@ popb4smtp_challenge (CamelSasl *sasl, GByteArray *token, CamelException *ex)
 		return NULL;
 	}
 
-	if (strncasecmp(popuri, "pop:", 4) != 0) {
+	if (g_ascii_strncasecmp(popuri, "pop:", 4) != 0) {
 		camel_exception_setv(ex, 1, _("POP Before SMTP auth using a non-pop source"));
 		return NULL;
 	}
 
 	/* check if we've done it before recently in this session */
-	now = time(0);
+	now = time(NULL);
 
 	/* need to lock around the whole thing until finished with timep */
 
