@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -29,12 +29,14 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <string.h>
-#include <sys/stat.h>
 #include <unistd.h>
+#include <sys/stat.h>
 
+#include <glib.h>
 #include <glib/gstdio.h>
 
-#include "libedataserver/e-data-server-util.h"
+#include <libedataserver/e-data-server-util.h>
+
 #include "camel-file-utils.h"
 #include "camel-private.h"
 #include "camel-uid-cache.h"
@@ -167,15 +169,13 @@ camel_uid_cache_save (CamelUIDCache *cache)
 	cache->expired = 0;
 	g_hash_table_foreach (cache->uids, maybe_write_uid, cache);
 	
-	if (cache->fd == -1)
-		goto exception;
-	
 	if (fsync (fd) == -1)
 		goto exception;
 	
 	close (fd);
 	fd = -1;
-	
+	cache->fd = -1;
+
 	if (g_rename (filename, cache->filename) == -1)
 		goto exception;
 	
@@ -189,7 +189,7 @@ camel_uid_cache_save (CamelUIDCache *cache)
 	
 #ifdef ENABLE_SPASMOLYTIC
 	if (fd != -1) {
-		/**
+		/*
 		 * If our new cache size is larger than the old cache,
 		 * even if we haven't finished writing it out
 		 * successfully, we should still attempt to replace
@@ -202,21 +202,23 @@ camel_uid_cache_save (CamelUIDCache *cache)
 		 * uids to make up for the difference in size (or
 		 * more), then we should replace the old cache with
 		 * the new cache as well.
-		 **/
+		 */
 		
 		if (g_stat (cache->filename, &st) == 0 &&
 		    (cache->size > st.st_size || cache->size + cache->expired > st.st_size)) {
 			if (ftruncate (fd, (off_t) cache->size) != -1) {
 				cache->size = 0;
 				cache->expired = 0;
-				goto overwrite;
+				goto overwrite; /* FIXME: no such label */
 			}
-		}
-		
-		close (fd);
+		}		
 	}
 #endif
-	
+	if (fd != -1) {
+		close (fd);
+		cache->fd = -1;
+	}
+
 	g_unlink (filename);
 	g_free (filename);
 	
