@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -23,21 +23,22 @@
 #include <config.h>
 #endif
 
-#include <sys/types.h>
-#include <sys/stat.h>
+#include <dirent.h>
 #include <errno.h>
 #include <string.h>
 #include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
-#include <dirent.h>
+#include <glib/gi18n-lib.h>
 
-#include "camel-maildir-store.h"
-#include "camel-maildir-folder.h"
 #include "camel-exception.h"
-#include "camel-url.h"
 #include "camel-private.h"
+#include "camel-url.h"
+
+#include "camel-maildir-folder.h"
+#include "camel-maildir-store.h"
 #include "camel-maildir-summary.h"
-#include "camel-i18n.h"
 
 #define d(x)
 
