@@ -16,11 +16,12 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <iconv.h>
 
 enum {
@@ -91,7 +92,7 @@ static int num_iso10646_tests = sizeof (iso10646_tests) / sizeof (CharInfo);
 
 int main (int argc, char **argv)
 {
-	unsigned int bits, iso8859, iso2022, iso10646;
+	unsigned int iso8859, iso2022, iso10646;
 	CharInfo *info;
 	iconv_t cd;
 	FILE *fp;
