@@ -185,8 +185,8 @@ enum ptime_locale_status { not, loc, raw };
 
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, write to the Free
-   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-   02111-1307 USA.  */
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+   02110-1301 USA.  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -1496,6 +1496,9 @@ parse_with_strptime (const char *value, struct tm *result, const char **formats,
 	locale_str = g_locale_from_utf8 (value, -1, NULL, NULL, NULL);
 	pos = (const char *) locale_str;
 
+	if (!locale_str)
+		return E_TIME_PARSE_INVALID;
+	
 	/* Skip whitespace */
 	while (n = (int)((unsigned char)*pos), isspace (n) != 0)
 		pos++;
